@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 
-
 import sys
 from os import listdir, environ
 from os.path import dirname
@@ -18,17 +17,15 @@ from clang.cindex import CursorKind
 from jinja2 import Environment, FileSystemLoader
 import logging
 
-if environ.get('HAMMOCK_DEBUG'):
-    logging.basicConfig(level=logging.DEBUG)
-
 
 class Variable:
-    def __init__(self, type: str, name: str) -> None:
+    def __init__(self, type: str, name: str, size: int = 0) -> None:
         self.type = type
         self.name = name
+        self.size = size
 
     def get_definition(self) -> str:
-        return f"{self.type} {self.name}"
+        return f"{self.type} {self.name}" + (f"[{self.size}]" if self.size > 0 else "")
 
 
 class Function:
@@ -84,10 +81,10 @@ class MockupWriter:
         if name not in self.headers:
             self.headers.append(name)
 
-    def add_variable(self, type: str, name: str) -> None:
+    def add_variable(self, type: str, name: str, size: int = 0) -> None:
         """Add a variable definition"""
         print(f"INFO: HammocKing: Create mockup for variable {name}")
-        self.variables.append(Variable(type, name))
+        self.variables.append(Variable(type, name, size))
 
     def add_function(self, type: str, name: str, params: List[Tuple[str, str]] = []) -> None:
         """Add a variable definition"""
@@ -114,6 +111,9 @@ class MockupWriter:
         template = Path(Path(template_filename).stem)
         return template.stem + (self.suffix if self.suffix else "") + template.suffix
 
+    def default_language_mode(self) -> str:
+        return 'c++' if self.mockup_style in ["gmock"] else 'c'
+
 
 class Hammock:
     def __init__(self, symbols: List[str], cmd_args: List[str] = [], mockup_style="gmock", suffix=None):
@@ -134,6 +134,9 @@ class Hammock:
             "args": self.cmd_args,
             "options": TranslationUnit.PARSE_SKIP_FUNCTION_BODIES | TranslationUnit.PARSE_INCOMPLETE,
         }
+        # Determine language mode, if not explicitly given
+        if not any(arg.startswith('-x') for arg in parseOpts["args"]):
+            parseOpts["args"].append('-x' + self.writer.default_language_mode())
 
         if issubclass(type(input), Path):
             # Read a path
@@ -149,9 +152,15 @@ class Hammock:
         self.logger.debug(f"Command arguments: {parseOpts['args']}")
         for child in translation_unit.cursor.get_children():
             if child.spelling in self.symbols:
-                self.writer.add_header(str(child.location.file))
+                in_header = child.location.file.name != translation_unit.spelling
+                if in_header:  # We found it in the Source itself. Better not include the whole source!
+                    self.writer.add_header(str(child.location.file))
                 if child.kind == CursorKind.VAR_DECL:
-                    self.writer.add_variable(child.type.spelling, child.spelling)
+                    child_type_array_size = child.type.get_array_size()
+                    if child_type_array_size > 0:
+                        self.writer.add_variable(child.type.element_type.spelling, child.spelling, child_type_array_size)
+                    else:
+                        self.writer.add_variable(child.type.spelling, child.spelling)
                 elif child.kind == CursorKind.FUNCTION_DECL:
                     self.writer.add_function(
                         child.type.get_result().spelling,
@@ -171,7 +180,7 @@ class Hammock:
 
 
 class NmWrapper:
-    regex = r"\s*U\s+([^_]\S*)"
+    regex = r"\s*U\s+((?!_|llvm_)\S*)"
 
     def __init__(self, plink: Path):
         self.plink = plink
@@ -193,7 +202,7 @@ class NmWrapper:
                 match = re.match(self.regex, line)
                 if match:
                     self.undefined_symbols.append(match.group(1))
-            assert p.returncode == None
+            assert p.returncode is None
 
 
 def main(pargv):
@@ -203,14 +212,16 @@ def main(pargv):
     group_symbols_xor_plink.add_argument("--symbols", "-s", help="Symbols to mock", nargs="+")
     group_symbols_xor_plink.add_argument("--plink", "-p", help="Path to partially linked object", type=Path)
 
+    arg.add_argument("--debug", "-d", help="Debugging", required=False, default=False, action="store_true")
     arg.add_argument("--outdir", "-o", help="Output directory", required=True, type=Path)
     arg.add_argument("--sources", help="List of source files to be parsed", type=Path, required=True, nargs="+")
 
     arg.add_argument("--style", "-t", help="Mockup style to output", required=False, default="gmock")
     arg.add_argument("--suffix", help="Suffix to be added to the generated files", required=False)
-
     args, cmd_args = arg.parse_known_args(args=pargv)
 
+    if args.debug:
+        logging.basicConfig(level=logging.DEBUG)
     if not args.symbols:
         args.symbols = NmWrapper(args.plink).get_undefined_symbols()
 
