@@ -11,21 +11,21 @@ int a_get_y2(){
     if(0 != mockup_global_ptr)
         return mockup_global_ptr->a_get_y2();
     else
-        return 0;
+        return (int)0;
 } /* a_get_y2 */
 
 int a_get_y3_and_set_u5(int u5){
     if(0 != mockup_global_ptr)
         return mockup_global_ptr->a_get_y3_and_set_u5(u5);
     else
-        return 0;
+        return (int)0;
 } /* a_get_y3_and_set_u5 */
 
 a_y5_t a_get_y5(){
     if(0 != mockup_global_ptr)
         return mockup_global_ptr->a_get_y5();
     else
-        return 0;
+        return (a_y5_t)0;
 } /* a_get_y5 */
 
 void a_get_y6(int* y6){
@@ -37,7 +37,7 @@ int c_get_y3_and_set_u5(int u5){
     if(0 != mockup_global_ptr)
         return mockup_global_ptr->c_get_y3_and_set_u5(u5);
     else
-        return 0;
+        return (int)0;
 } /* c_get_y3_and_set_u5 */
 
 void c_set_u2(int u2){
